searchData={"items":[{"type":"module","title":"Autumn","doc":"Syntax highlighter for source code parsed with Tree-Sitter and styled with Helix Editor themes.","ref":"Autumn.html"},{"type":"module","title":"Features - Autumn","doc":"- Support [multiple languages](https://github.com/leandrocp/autumn/blob/main/native/inkjet_nif/Cargo.toml#L16) and [100+ themes](https://github.com/leandrocp/autumn/tree/main/priv/themes). Check out some samples at https://autumn-30n.pages.dev\n- Used by [MDEx](https://github.com/leandrocp/mdex) - a fast 100% CommonMark-compatible GitHub Flavored Markdown parser and formatter for Elixir\n- Use Rust's [inkjet crate](https://crates.io/crates/inkjet) under the hood","ref":"Autumn.html#module-features"},{"type":"module","title":"Installation - Autumn","doc":"Add `:autumn` dependency:\n\n```elixir\ndef deps do\n  [\n    {:autumn, \"~> 0.1\"}\n  ]\nend\n```","ref":"Autumn.html#module-installation"},{"type":"module","title":"Usage - Autumn","doc":"```elixir\nAutumn.highlight!(\"elixir\", \"Atom.to_string(:elixir)\") |> IO.puts()\n#=>  \n#=>    \n#=>      Atom  .  to_string  (  :elixir  ) \n#=>    \n#=>  \n```","ref":"Autumn.html#module-usage"},{"type":"module","title":"Styles mode - Autumn","doc":"There are 2 modes to syntax highlight source code, the default is embedding inline styles in each one of the generated tokens, and the other more effective is relying on CSS classes to style the tokens.\n\n#","ref":"Autumn.html#module-styles-mode"},{"type":"module","title":"Inline - Autumn","doc":"Inlining styles will look like:\n\n```html\n Atom \n```\n\nThat mode is easy and works fine for simple cases but in pages with multiple code blocks you might want to use CSS instead.\n\n#","ref":"Autumn.html#module-inline"},{"type":"module","title":"CSS - Autumn","doc":"First you need to disable inline styles by passing `false` to the `:inline_style` option:\n\n```elixir\nAutumn.highlight!(\"elixir\", \"Atom.to_string(:elixir)\", inline_style: false) |> IO.puts()\n# rest ommited for brevity\n# `style` is no longer generated\n#=>  \n```\n\nAnd then you need to serve any of of the [available CSS themes](https://github.com/leandrocp/autumn/tree/main/priv/static/css) in your app.\n\nIf you're using Phoenix you can serve them from your app, just add the following `Plug` into your app's `endpoint.ex` file:\n\n```elixir\nplug Plug.Static,\n  at: \"/themes\",\n  from: {:autumn, \"priv/static/css/\"},\n  only: [\"dracula.css\"] # choose any theme you want\n```\n\nThe style will be served at `/themes/dracula.css`. In your local environemnt that resolves to http://localhost:4000/themes/dracula.css so finally add to your template:\n\n```html\n \n```\n\nYou can also copy the content of that theme file into a ` ` tag in your template or serve that file from a CDN.","ref":"Autumn.html#module-css"},{"type":"module","title":"Samples - Autumn","doc":"Visit https://autumn-30n.pages.dev to see all [available samples](https://github.com/leandrocp/autumn/tree/main/priv/generated/samples) like the ones below:","ref":"Autumn.html#module-samples"},{"type":"module","title":"Looking for help with your Elixir project? - Autumn","doc":"At DockYard we are [ready to help you build your next Elixir project](https://dockyard.com/phoenix-consulting).\nWe have a unique expertise in Elixir and Phoenix development that is unmatched and we love to [write about Elixir](https://dockyard.com/blog/categories/elixir).\n\nHave a project in mind? [Get in touch](https://dockyard.com/contact/hire-us)!","ref":"Autumn.html#module-looking-for-help-with-your-elixir-project"},{"type":"module","title":"Acknowledgements - Autumn","doc":"* [Logo](https://www.flaticon.com/free-icons/fall) created by by pongsakornRed - Flaticon\n* [Logo font](https://fonts.google.com/specimen/Sacramento) designed by [Astigmatic](http://www.astigmatic.com)","ref":"Autumn.html#module-acknowledgements"},{"type":"function","title":"Autumn.highlight/2","doc":"Highlights the `source_code`.","ref":"Autumn.html#highlight/2"},{"type":"function","title":"Options - Autumn.highlight/2","doc":"* `:language` (default: `nil`) - the language to use for highlighting.\nBesides a language name, you can also pass a filename or extension. Note that an invalid language or `nil` will fallback\nto rendering plain text (no colors) using the background and foreground colors defined by the current theme.\n* `:theme` (default: `\"onedark\"`) - accepts any theme listed [here](https://github.com/leandrocp/autumn/tree/main/priv/themes).\nYou should pass the filename without special chars and without extension,\nfor example pass `theme: \"adwaita_dark\"` to use the [Adwaita Dark](https://github.com/leandrocp/autumn/blob/main/priv/themes/adwaita-dark.toml) theme\nor `theme: \"penumbra\"` to use the [Penumbra+](https://github.com/leandrocp/autumn/blob/main/priv/themes/penumbra%2B.toml) theme.\n* `:pre_class` (default: `nil`) - the CSS class to inject into the wrapping parent ` ` tag.\nBy default it renders a ` ` tag with the `autumn-hl` class which will be merged with the class passed into this option.\n* `:inline_style` (default: `true`) - see more info on the module doc.","ref":"Autumn.html#highlight/2-options"},{"type":"function","title":"Examples - Autumn.highlight/2","doc":"Passing a language name:\n\n    iex> {:ok, hl} = Autumn.highlight(\"Atom.to_string(:elixir)\", language: \"elixir\")\n    iex> IO.puts(hl)\n    #=>    Atom  .  to_string  (  :elixir  )   \n\nOr more options with a file extension:\n\n    iex> {:ok, hl} = Autumn.highlight(\"Atom.to_string(:elixir)\", language: \".ex\", inline_style: false, pre_class: \"my-app-code\")\n    iex> IO.puts(hl)\n    #=>    Atom  .  to_string  (  :elixir  )   \n\nAnd no language results in plain text:\n\n    iex> {:ok, hl} = Autumn.highlight(\"Atom.to_string(:elixir)\")\n    iex> IO.puts(hl)\n    #=>   Atom.to_string(:elixir)","ref":"Autumn.html#highlight/2-examples"},{"type":"function","title":"Autumn.highlight/3","doc":"","ref":"Autumn.html#highlight/3"},{"type":"function","title":"Autumn.highlight!/2","doc":"Same as `highlight/2` but raises in case of failure.","ref":"Autumn.html#highlight!/2"},{"type":"function","title":"Autumn.highlight!/3","doc":"","ref":"Autumn.html#highlight!/3"},{"type":"type","title":"Autumn.lang_filename_ext/0","doc":"A language name, filename, or extesion.","ref":"Autumn.html#t:lang_filename_ext/0"},{"type":"type","title":"Examples - Autumn.lang_filename_ext/0","doc":"- \"elixir\"\n    - \"main.rb\"\n    - \".rs\"\n    - \"php\"","ref":"Autumn.html#t:lang_filename_ext/0-examples"},{"type":"task","title":"mix autumn.generate_css","doc":"","ref":"Mix.Tasks.Autumn.GenerateCss.html"},{"type":"task","title":"mix autumn.generate_samples","doc":"","ref":"Mix.Tasks.Autumn.GenerateSamples.html"},{"type":"task","title":"mix autumn.generate_themes_rs","doc":"","ref":"Mix.Tasks.Autumn.GenerateThemesRs.html"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.2.2 (2024-04-11) - Changelog","doc":"#","ref":"changelog.html#0-2-2-2024-04-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add more languages: eex, elm, iex, jsx, ocaml, ocam-interface, svelte, tsx, vim","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.2.1 (2024-04-11) - Changelog","doc":"#","ref":"changelog.html#0-2-1-2024-04-11"},{"type":"extras","title":"Fixes - Changelog","doc":"* Include CSS files in package","ref":"changelog.html#fixes"},{"type":"extras","title":"0.2.0 (2024-04-10) - Changelog","doc":"#","ref":"changelog.html#0-2-0-2024-04-10"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to Inkjet v0.10.4\n  * Update themes\n  * Update languages\n  * Add Pascal language\n  * Add new option `:inline_style` to enable/disable inline styles\n  * Genrate CSS files\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Fixes - Changelog","doc":"* Name of CSS classes should be unique and composable","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.5 (2023-11-20) - Changelog","doc":"#","ref":"changelog.html#0-1-5-2023-11-20"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add themes base16-tomorrow and base16-tomorrow-night - @paradox460","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.4 (2023-10-25) - Changelog","doc":"#","ref":"changelog.html#0-1-4-2023-10-25"},{"type":"extras","title":"Fixes - Changelog","doc":"* Remove newlines to avoid breaking formatting","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.3 (2023-10-24) - Changelog","doc":"#","ref":"changelog.html#0-1-3-2023-10-24"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add translate=\"no\" attr in ` ` tag\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Fixes - Changelog","doc":"* Fix Javascript grammar\n  * Fix Typescript grammar\n\n#","ref":"changelog.html#fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add icon","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.2 (2023-09-29) - Changelog","doc":"#","ref":"changelog.html#0-1-2-2023-09-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add logo\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Fixes - Changelog","doc":"* Fix broken image links in docs","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.1 (2023-09-29) - Changelog","doc":"#","ref":"changelog.html#0-1-1-2023-09-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Fallback to plain text on invalid language\n  * Add samples\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Fixes - Changelog","doc":"* Do not render the first line empty\n  * Make sure languages are loaded correctly","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.0 (2023-09-28) - Changelog","doc":"#","ref":"changelog.html#0-1-0-2023-09-28"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Autumn.highlight/3`\n  * Add `Autumn.highlight!/3`","ref":"changelog.html#enhancements"}],"content_type":"text/markdown"}